@@ -1,7 +1,7 @@
 """
 Type annotations for iot-data service client.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client/)
 
 Usage::
 
@@ -63,7 +63,7 @@ class Exceptions:
 class IoTDataPlaneClient(BaseClient):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-data.html#IoTDataPlane.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client/)
+    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client/)
     """
 
     meta: ClientMeta
@@ -74,7 +74,7 @@ class IoTDataPlaneClient(BaseClient):
         IoTDataPlaneClient exceptions.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-data.html#IoTDataPlane.Client.exceptions)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client/#exceptions)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client/#exceptions)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
@@ -82,7 +82,7 @@ class IoTDataPlaneClient(BaseClient):
         Check if an operation can be paginated.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-data.html#IoTDataPlane.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client/#can_paginate)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client/#can_paginate)
         """
 
     def delete_thing_shadow(
@@ -92,7 +92,7 @@ class IoTDataPlaneClient(BaseClient):
         Deletes the shadow for the specified thing.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-data.html#IoTDataPlane.Client.delete_thing_shadow)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client/#delete_thing_shadow)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client/#delete_thing_shadow)
         """
 
     def generate_presigned_url(
@@ -106,7 +106,7 @@ class IoTDataPlaneClient(BaseClient):
         Generate a presigned url given a client, its method, and arguments.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-data.html#IoTDataPlane.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client/#generate_presigned_url)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client/#generate_presigned_url)
         """
 
     def get_retained_message(self, *, topic: str) -> GetRetainedMessageResponseTypeDef:
@@ -114,7 +114,7 @@ class IoTDataPlaneClient(BaseClient):
         Gets the details of a single retained message for the specified topic.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-data.html#IoTDataPlane.Client.get_retained_message)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client/#get_retained_message)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client/#get_retained_message)
         """
 
     def get_thing_shadow(
@@ -124,7 +124,7 @@ class IoTDataPlaneClient(BaseClient):
         Gets the shadow for the specified thing.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-data.html#IoTDataPlane.Client.get_thing_shadow)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client/#get_thing_shadow)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client/#get_thing_shadow)
         """
 
     def list_named_shadows_for_thing(
@@ -134,7 +134,7 @@ class IoTDataPlaneClient(BaseClient):
         Lists the shadows for the specified thing.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-data.html#IoTDataPlane.Client.list_named_shadows_for_thing)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client/#list_named_shadows_for_thing)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client/#list_named_shadows_for_thing)
         """
 
     def list_retained_messages(
@@ -144,7 +144,7 @@ class IoTDataPlaneClient(BaseClient):
         Lists summary information about the retained messages stored for the account.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-data.html#IoTDataPlane.Client.list_retained_messages)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client/#list_retained_messages)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client/#list_retained_messages)
         """
 
     def publish(
@@ -153,27 +153,27 @@ class IoTDataPlaneClient(BaseClient):
         topic: str,
         qos: int = ...,
         retain: bool = ...,
-        payload: Union[bytes, IO[bytes], StreamingBody] = ...
+        payload: Union[str, bytes, IO[Any], StreamingBody] = ...
     ) -> None:
         """
         Publishes an MQTT message.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-data.html#IoTDataPlane.Client.publish)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client/#publish)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client/#publish)
         """
 
     def update_thing_shadow(
         self,
         *,
         thingName: str,
-        payload: Union[bytes, IO[bytes], StreamingBody],
+        payload: Union[str, bytes, IO[Any], StreamingBody],
         shadowName: str = ...
     ) -> UpdateThingShadowResponseTypeDef:
         """
         Updates the shadow for the specified thing.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-data.html#IoTDataPlane.Client.update_thing_shadow)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client/#update_thing_shadow)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client/#update_thing_shadow)
         """
 
     def get_paginator(
@@ -181,5 +181,5 @@ class IoTDataPlaneClient(BaseClient):
     ) -> ListRetainedMessagesPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/iot-data.html#IoTDataPlane.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client/#get_paginator)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client/#get_paginator)
         """
